@@ -22,7 +22,7 @@ struct GIFelement *current;
 int delete = FALSE;
 int optimize = FALSE;
 int histogram = FALSE;
-int interlaced = -1;
+int interlaced = PNG_INTERLACE_LAST;
 int progress = FALSE;
 int verbose = FALSE;
 int recover = FALSE;
@@ -117,7 +117,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
     png_info *info_ptr = xalloc(sizeof (png_info));
     int p;
     int gray_bitdepth;
-    png_color pal_rgb[MAXCMSIZE];
+    png_color pal_rgb[MAXCMSIZE], *pltep;
     png_byte pal_trans[MAXCMSIZE];
     png_color_16 color16trans, color16back;
     byte buffer[24]; /* used for gIFt and gIFg */
@@ -297,30 +297,25 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
     }
 
     /* set basic image properties: width/height, type, bit depth, interlace */
-    info_ptr->width = current->imagestruct->width;
-    info_ptr->height = current->imagestruct->height;
-    info_ptr->bit_depth = bitdepth;
-    info_ptr->color_type = gray ? PNG_COLOR_TYPE_GRAY : PNG_COLOR_TYPE_PALETTE;
-    if (interlaced == -1)
-	info_ptr->interlace_type = current->imagestruct->interlace;
-    else
-	info_ptr->interlace_type = interlaced;
+    if (interlaced == PNG_INTERLACE_LAST)
+	interlaced = current->imagestruct->interlace ? PNG_INTERLACE_ADAM7 : PNG_INTERLACE_NONE;
+
+    png_set_IHDR(png_ptr, info_ptr, 
+		 current->imagestruct->width, current->imagestruct->height,
+		 bitdepth, 
+		 gray ? PNG_COLOR_TYPE_GRAY : PNG_COLOR_TYPE_PALETTE,
+		 interlaced, 
+		 PNG_COMPRESSION_TYPE_DEFAULT, PNG_FILTER_TYPE_DEFAULT);
 
     /* if the GIF specified an aspect ratio, turn it into a pHYs chunk */
-    if (GifScreen.AspectRatio != 0 && GifScreen.AspectRatio != 49) {
-	info_ptr->x_pixels_per_unit = GifScreen.AspectRatio+15;
-	info_ptr->y_pixels_per_unit = 64;
-	info_ptr->phys_unit_type = PNG_RESOLUTION_UNKNOWN;
-	info_ptr->valid |= PNG_INFO_pHYs;
-    }
+    if (GifScreen.AspectRatio != 0 && GifScreen.AspectRatio != 49)
+	png_set_pHYs(png_ptr, info_ptr, 
+		     GifScreen.AspectRatio+15, 64, PNG_RESOLUTION_UNKNOWN);
 
     /* if the GIF specified an image offset, turn it into a oFFs chunk */
-    if (img->offset_x>0 && img->offset_y>0) {
-	info_ptr->x_offset = img->offset_x;
-	info_ptr->y_offset = img->offset_y;
-	info_ptr->offset_unit_type = PNG_OFFSET_PIXEL;
-	info_ptr->valid |= PNG_INFO_oFFs;
-    }
+    if (img->offset_x>0 && img->offset_y>0)
+	png_set_oFFs(png_ptr, info_ptr, 
+		     img->offset_x, img->offset_y, PNG_OFFSET_PIXEL);
 
     if (GifScreen.Background > 0) { /* no background for palette entry 0 */
 	/* if the background color doesn't appear in local palette, we just
@@ -329,9 +324,8 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 
 	if (gray) {
 	    if (is_gray(GifScreen.ColorMap[GifScreen.Background])) {
-		color16back.gray = remap[GifScreen.Background];
-		info_ptr->background = color16back;
-		info_ptr->valid |= PNG_INFO_bKGD;
+			color16back.gray = remap[GifScreen.Background];
+		png_set_bKGD(png_ptr, info_ptr, &color16back);
 	    }
 	} else {
 	    for (i = 0; i < MAXCMSIZE; i++) {
@@ -355,7 +349,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	    if (verbose > 2)
 		fprintf(stderr, "gif2png: handling grayscale transparency\n");
 	    color16trans.gray = remap[img->trans];
-	    info_ptr->trans_values = color16trans;
+	    png_set_tRNS(png_ptr, info_ptr, NULL, 0, &color16trans);
 	} else {
 	    if (verbose > 2)
 		fprintf(stderr, "gif2png: handling palette transparency\n");
@@ -363,8 +357,7 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	    for (i = 0; i < MAXCMSIZE; i++)
 		pal_trans[i] = 255;
 	    pal_trans[img->trans] = 0;
-	    info_ptr->trans = pal_trans;
-	    info_ptr->num_trans = img->trans+1;
+	    png_set_tRNS(png_ptr, info_ptr, pal_trans, img->trans+1, NULL);
 #else
 	    /* GRR NOTE:  may be inconsistent with background-color logic (above) */
 	    remapping = TRUE;
@@ -373,11 +366,9 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 	    remap[0] = img->trans;
 	    remap[img->trans] = 0;
 	    pal_trans[0] = 0;
-	    info_ptr->trans = pal_trans;
-	    info_ptr->num_trans = 1;
+	    png_set_tRNS(png_ptr, info_ptr, pal_trans, 1, NULL);
 #endif
 	}
-	info_ptr->valid |= PNG_INFO_tRNS;
     }
 
     /* generate the PNG palette */
@@ -390,20 +381,19 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 		pal_rgb[i].green = current->imagestruct->colors[remap[i]].green;
 		pal_rgb[i].blue  = current->imagestruct->colors[remap[i]].blue;
 	    }
-	    info_ptr->palette = pal_rgb;
+	    pltep = pal_rgb;
 	} else {
 	    if (verbose > 2)
 		fprintf(stderr, "Palette copied from GIF colors...\n");
-	    info_ptr->palette = current->imagestruct->colors;
+	    pltep = current->imagestruct->colors;
 	}
-	info_ptr->num_palette = last_color+1;
-	info_ptr->valid |= PNG_INFO_PLTE;
+	png_set_PLTE(png_ptr, info_ptr, pltep, last_color+1);
 
 	if (verbose > 2) {
 	    fprintf(stderr,"PNG palette generated with %d colors:\n",last_color+1);
 	    for (i = 0; i <= last_color; i++) {
 		fprintf(stderr, "(%3d, %3d, %3d)\n", 
-			info_ptr->palette[i].red, info_ptr->palette[i].blue, info_ptr->palette[i].green);  
+			pltep[i].red, pltep[i].blue, pltep[i].green);  
 	    }
 	}
     }
@@ -434,28 +424,21 @@ int writefile(struct GIFelement *s,struct GIFelement *e, FILE *fp, int lastimg)
 		    histogr[i] = 0;
 		}
 	}
-	info_ptr->hist = histogr;
-	info_ptr->valid |= PNG_INFO_hIST;
+	png_set_hIST(png_ptr, info_ptr, histogr);
     }
 
     /* transcribe software chunk if necessary */
     if (software_chunk) {
-	software.compression = -1;
+	software.compression = PNG_TEXT_COMPRESSION_NONE;
 	software.key = "Software";
 	software.text = (char*)version;
 	software.text_length = strlen(software.text);
 
-	info_ptr->num_text = 1;
-	info_ptr->max_text = 1;
-	info_ptr->text = &software;
+	png_set_text(png_ptr, info_ptr, &software, 1);
     }
 
     png_write_info(png_ptr, info_ptr);
 
-    info_ptr->num_text = 0;
-    info_ptr->max_text = 0;
-    info_ptr->text = NULL;
-
     if (info_ptr->bit_depth<8)
 	png_set_packing(png_ptr);
 
@@ -787,11 +770,11 @@ int main(int argc, char *argv[])
 		break;
 
 	    case 'i':
-		interlaced = TRUE;
+		interlaced = PNG_INTERLACE_ADAM7;
 		break;
 
 	    case 'n':
-		interlaced = FALSE;
+		interlaced = PNG_INTERLACE_NONE;
 		break;
 
 	    case 'p':
